#ifndef SRC_IP_H
#define SRC_IP_H

#define LAN_PING_TIMEOUT 50

#include "gps.h"
#include "route.h"

struct arp_elt *get_src_ip_list(netdev *nd, u_int16_t pingport, int *nbip, u_int32_t dstip);

#endif
